@@ -33,32 +33,31 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  */
-
-#include <config.h>
+#include <config-kxsconfig.h>
 
 #include <stdlib.h>
 #include <qlayout.h>
 #include <qtimer.h>
-#include <qvbox.h>
+#include <kvbox.h>
 #include <qlabel.h>
 #include <qfileinfo.h>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QBoxLayout>
 
 #include <kdebug.h>
 #include <kapplication.h>
 #include <kconfig.h>
-#include <kdialogbase.h>
-#include <kprocess.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
+#include <kshell.h>
 #include <kmessagebox.h>
 
 #include "kxsconfig.h"
 #include "kxscontrol.h"
 #include "kxsxml.h"
 
-template class QPtrList<KXSConfigItem>;
-
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <X11/IntrinsicP.h>
@@ -76,10 +75,15 @@ const uint widgetEventMask =                 // X event mask
       );
 
 KXSConfigDialog::KXSConfigDialog(const QString &filename, const QString &name)
-  : KDialogBase(Plain, name, Ok| Cancel, Ok, 0, 0, false),
-    mFilename(filename), mPreviewProc(0), mKilled(true)
+  : KDialog(0),
+    mFilename(filename), mPreviewProc(0), mKilled(false)
 {
-    int slash = filename.findRev('/');
+    Q_UNUSED(name)
+
+    setButtons(Ok| Cancel);
+    setDefaultButton( Ok);
+    setModal(false);
+    int slash = filename.lastIndexOf('/');
     if (slash >= 0)
 	mConfigFile = filename.mid(slash+1);
     else
@@ -87,13 +91,20 @@ KXSConfigDialog::KXSConfigDialog(const QString &filename, const QString &name)
 
     mExeName = mConfigFile;
     mConfigFile += "rc";
+    connect( this,SIGNAL(okClicked()),this,SLOT(slotOk()));
+    connect( this,SIGNAL(cancelClicked()),this,SLOT(slotCancel()));
 }
 
 bool KXSConfigDialog::create()
 {
-    QVBoxLayout *topLayout = new QVBoxLayout(plainPage(), spacingHint());
-    QHBoxLayout *layout = new QHBoxLayout(topLayout, spacingHint());
-    QVBox *controlLayout = new QVBox(plainPage());
+    QWidget *main = new QWidget(this);
+    setMainWidget(main);
+    QVBoxLayout *topLayout = new QVBoxLayout(main);
+    topLayout->setSpacing(spacingHint());
+    QHBoxLayout *layout = new QHBoxLayout();
+    topLayout->addLayout(layout);
+    layout->setSpacing(spacingHint());
+    KVBox *controlLayout = new KVBox(main);
     controlLayout->setSpacing(spacingHint());
     layout->addWidget(controlLayout);
     ((QBoxLayout*)controlLayout->layout())->addStrut(120);
@@ -105,16 +116,19 @@ bool KXSConfigDialog::create()
     xmlFile = XSCREENSAVER_CONFIG_DIR;
 #endif
 
-    xmlFile += "/" + mExeName + ".xml";
+    xmlFile += '/' + mExeName + ".xml";
     if ( QFile::exists( xmlFile ) ) {
 	// We can use the xscreensaver xml config files.
 	KXSXml xmlParser(controlLayout);
 	xmlParser.parse( xmlFile );
-	mConfigItemList = *xmlParser.items();
+	mConfigItemList = xmlParser.items();
 	QWidget *spacer = new QWidget(controlLayout);
 	controlLayout->setStretchFactor(spacer, 1 );
-	if ( !xmlParser.description().isEmpty() ) {
-	    QLabel *l = new QLabel( xmlParser.description(), plainPage() );
+	QString descr = xmlParser.description();
+	if ( !descr.isEmpty() ) {
+	    descr = descr.replace('\n', ' ').simplified();
+	    QLabel *l = new QLabel( i18n( descr.toUtf8() ), main );
+	    l->setWordWrap( 1 );
 	    topLayout->addWidget( l );
 	}
     } else {
@@ -123,8 +137,8 @@ bool KXSConfigDialog::create()
 	while (true) {
 	    QString group = QString("Arg%1").arg(idx);
 	    if (config.hasGroup(group)) {
-		config.setGroup(group);
-		QString type = config.readEntry("Type");
+		KConfigGroup grp = config.group(group);
+		QString type = grp.readEntry("Type");
 		if (type == "Range") {
 		    KXSRangeControl *rc = new KXSRangeControl(controlLayout, group, config);
 		    mConfigItemList.append(rc);
@@ -150,46 +164,48 @@ bool KXSConfigDialog::create()
 	    return false;
     }
 
-    QPtrListIterator<KXSConfigItem> it( mConfigItemList );
-    KXSConfigItem *item;
-    while ( (item = it.current()) != 0 ) {
-	++it;
-	item->read( config );
-        QWidget *i = dynamic_cast<QWidget*>(item);
-        if (i) {
-            connect( i, SIGNAL(changed()), SLOT(slotChanged()) );
+    for ( int i = 0; i < mConfigItemList.size(); i++ ) {
+        KXSConfigItem *item = mConfigItemList[i];
+        item->read( config );
+        QWidget *widget = dynamic_cast<QWidget*>( item );
+        if ( widget ) {
+            connect( widget, SIGNAL(changed()), SLOT(slotChanged()) );
         }
     }
 
     mPreviewProc = new KProcess;
-    connect(mPreviewProc, SIGNAL(processExited(KProcess *)),
-	    SLOT(slotPreviewExited(KProcess *)));
+    connect(mPreviewProc, SIGNAL(finished(int,QProcess::ExitStatus)),
+	    SLOT(slotPreviewProcFinished(int,QProcess::ExitStatus)));
 
     mPreviewTimer = new QTimer(this);
+    mPreviewTimer->setSingleShot(true);
     connect(mPreviewTimer, SIGNAL(timeout()), SLOT(slotNewPreview()));
 
-    mPreview = new QWidget(plainPage());
+    mPreview = new QWidget(main);
     mPreview->setFixedSize(250, 200);
-    //  mPreview->setBackgroundMode(QWidget::NoBackground);
-    mPreview->setBackgroundColor(Qt::black);
+    {
+        QPalette palette;
+        palette.setColor(mPreview->backgroundRole(), Qt::black);
+        mPreview->setPalette(palette);
+	mPreview->setAutoFillBackground(true);
+    }
 
-    layout->add(mPreview);
+    layout->addWidget(mPreview);
     show();
 
     // So that hacks can XSelectInput ButtonPressMask
-    XSelectInput(qt_xdisplay(), mPreview->winId(), widgetEventMask );
+    XSelectInput(QX11Info::display(), mPreview->winId(), widgetEventMask );
 
-    slotPreviewExited(0);
+    startProcess();
     return true;
 }
 
 //---------------------------------------------------------------------------
 KXSConfigDialog::~KXSConfigDialog()
 {
-  if (mPreviewProc && mPreviewProc->isRunning()) {
-    int pid = mPreviewProc->pid();
+  if (mPreviewProc && mPreviewProc->state() == QProcess::Running) {
     mPreviewProc->kill();
-    waitpid(pid, (int *)0, 0);
+    mPreviewProc->waitForFinished(5000);
     delete mPreviewProc;
   }
 }
@@ -198,62 +214,62 @@ KXSConfigDialog::~KXSConfigDialog()
 QString KXSConfigDialog::command()
 {
   QString cmd;
-  KXSConfigItem *item;
 
-  for (item = mConfigItemList.first(); item != 0; item = mConfigItemList.next())
+  for (int i = 0; i < mConfigItemList.size(); i++)
   {
-    cmd += " " + item->command();
+    if (mConfigItemList[i]) {
+      cmd += " " + mConfigItemList[i]->command();
+    }
   }
 
   return cmd;
 }
 
 //---------------------------------------------------------------------------
-void KXSConfigDialog::slotPreviewExited(KProcess *)
+void KXSConfigDialog::startProcess()
 {
+    mKilled = false;
+    mPreviewProc->clearProgram();
+    QString saver = QString( "%1 -window-id 0x%2" )
+        .arg( mFilename )
+        .arg( long(mPreview->winId()), 0, 16 );
+    saver += command();
+    saver = saver.trimmed();
+
+    kDebug() << "Command: " <<  saver;
+
+    int i = 0;
+    QString exe;
+    while ( !saver[i].isSpace() ) {
+        exe += saver[i++];
+    }
+    // work around a KStandarDirs::findExe() "feature" where it looks in
+    // $KDEDIR/bin first no matter what and sometimes finds the wrong executable
+    QFileInfo checkExe;
+    QString saverdir = QString(XSCREENSAVER_HACKS_DIR "/") + exe;
+    QString path;
+    checkExe.setFile(saverdir);
+    if (checkExe.exists() && checkExe.isExecutable() && checkExe.isFile())
+    {
+        path = saverdir;
+    }
+    if (!path.isEmpty()) {
+        (*mPreviewProc) << path;
+
+        (*mPreviewProc) << KShell::splitArgs(saver.mid(i));
+
+        mPreviewProc->start();
+    }
+}
+
+//---------------------------------------------------------------------------
+void KXSConfigDialog::slotPreviewProcFinished(int exitCode, QProcess::ExitStatus exitStatus)
+{
+    Q_UNUSED(exitCode)
+    Q_UNUSED(exitStatus)
+
     if ( mKilled ) {
-	mKilled = false;
-	mPreviewProc->clearArguments();
-	QString saver;
-	saver.sprintf( "%s -window-id 0x%lX", mFilename.latin1(), long(mPreview->winId()) );
-	saver += command();
-	kdDebug() << "Command: " <<  saver << endl;
-
-	unsigned int i = 0;
-	QString word;
-	saver = saver.stripWhiteSpace();
-	while ( !saver[i].isSpace() ) word += saver[i++];
-	//work around a KStandarDirs::findExe() "feature" where it looks in $KDEDIR/bin first no matter what and sometimes finds the wrong executable
-	QFileInfo checkExe;
-	QString saverdir = QString("%1/%2").arg(XSCREENSAVER_HACKS_DIR).arg(word);
-	QString path;
-	checkExe.setFile(saverdir);
-	if (checkExe.exists() && checkExe.isExecutable() && checkExe.isFile())
-	{
-		path = saverdir;
-	}
-	if (!path.isEmpty()) {
-	    (*mPreviewProc) << path;
-
-	    bool inQuotes = false;
-	    while ( i < saver.length() ) {
-		word = "";
-		while ( saver[i].isSpace() && i < saver.length() ) i++;
-		while ( (!saver[i].isSpace() || inQuotes) && i < saver.length() ) {
-		    if ( saver[i] == '\"' ) {
-			inQuotes = !inQuotes;
-		    } else {
-			word += saver[i];
-		    }
-		    i++;
-		}
-		if (!word.isEmpty()) {
-		    (*mPreviewProc) << word;
-		}
-	    }
-
-	    mPreviewProc->start();
-	}
+        startProcess();
     } else {
 	// stops us from spawning the hack really fast, but still not the best
 	QString path = KStandardDirs::findExe(mFilename, XSCREENSAVER_HACKS_DIR);
@@ -267,32 +283,30 @@ void KXSConfigDialog::slotPreviewExited(KProcess *)
 //---------------------------------------------------------------------------
 void KXSConfigDialog::slotNewPreview()
 {
-  if (mPreviewProc->isRunning()) {
+  if (mPreviewProc->state() == QProcess::Running) {
     mKilled = true;
     mPreviewProc->kill(); // restarted in slotPreviewExited()
   } else {
-    slotPreviewExited(0);
+    startProcess();
   }
 }
 
 //---------------------------------------------------------------------------
 void KXSConfigDialog::slotChanged()
 {
-    if (mPreviewTimer->isActive())
-	mPreviewTimer->changeInterval(1000);
-    else
-	mPreviewTimer->start(1000, true);
+    mPreviewTimer->start(1000);
 }
 
 //---------------------------------------------------------------------------
 void KXSConfigDialog::slotOk()
 {
-  KXSConfigItem *item;
   KConfig config(mConfigFile);
 
-  for (item = mConfigItemList.first(); item != 0; item = mConfigItemList.next())
+  for (int i = 0; i < mConfigItemList.size(); i++)
   {
-    item->save(config);
+    if (mConfigItemList[i]) {
+      mConfigItemList[i]->save(config);
+    }
   }
 
   kapp->quit();
@@ -313,13 +327,6 @@ static const char description[] = I18N_NOOP("KDE X Screen Saver Configuration to
 
 static const char version[] = "3.0.0";
 
-static const KCmdLineOptions options[] =
-{
-   {"+screensaver", I18N_NOOP("Filename of the screen saver to configure"), 0},
-   {"+[savername]", I18N_NOOP("Optional screen saver name used in messages"), 0},
-   KCmdLineLastOption
-};
-
 static const char *defaults[] = {
 #include "XScreenSaver_ad.h"
  0
@@ -331,7 +338,14 @@ XrmDatabase db;
 
 int main(int argc, char *argv[])
 {
-  KCmdLineArgs::init(argc, argv, appName, I18N_NOOP("KXSConfig"), description, version);
+  KCmdLineArgs::init(argc, argv, appName, 0, ki18n("KXSConfig"), version, ki18n(description));
+
+
+  KCmdLineOptions options;
+
+  options.add("+screensaver", ki18n("Filename of the screen saver to configure"));
+
+  options.add("+[savername]", ki18n("Optional screen saver name used in messages"));
 
   KCmdLineArgs::addCmdLineOptions(options);
 
@@ -353,7 +367,7 @@ int main(int argc, char *argv[])
   // Teach Xt to use the Display that Qt has already opened.
   XtToolkitInitialize ();
   XtAppContext xtApp = XtCreateApplicationContext ();
-  Display *dpy = qt_xdisplay();
+  Display *dpy = QX11Info::display();
   XtAppSetFallbackResources (xtApp, const_cast<char**>(defaults));
   XtDisplayInitialize (xtApp, dpy, progname, progclass, 0, 0,
                        &dummyargc,
@@ -366,15 +380,14 @@ int main(int argc, char *argv[])
   XtGetApplicationNameAndClass (dpy, const_cast<char**>(&progname),
                                 const_cast<char**>(&progclass));
 
-  QString name = QString::fromLocal8Bit(args->arg(args->count() - 1));
+  QString name = args->arg(args->count() - 1);
   KXSConfigDialog *dialog=new KXSConfigDialog(args->arg(0), name);
   if ( dialog->create() ) {
       dialog->show();
-      app.setMainWidget(dialog);
       app.exec();
   } else {
       KMessageBox::sorry(0,
-	      i18n("No configuration available for %1").arg(name),
+	      i18n("No configuration available for %1", name),
 	      name );
   }
 
