@@ -21,6 +21,16 @@
 #include <qlayout.h>
 #include <qpainter.h>
 #include <qpixmap.h>
+//Added by qt3to4:
+#include <QPaintEvent>
+#include <Q3PointArray>
+#include <QEvent>
+#include <QBoxLayout>
+#include <Q3ValueList>
+#include <QShowEvent>
+#include <QResizeEvent>
+#include <QVBoxLayout>
+#include <QMouseEvent>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <klocale.h>
@@ -75,7 +85,7 @@ void GlowClientConfig::load(KDecorationFactory *factory)
 	closeButtonGlowColor = conf.readColorEntry(
 		"closeButtonGlowColor", &defaultCloseButtonColor);
 
-	showResizeHandle = conf.readBoolEntry("showResizeHandle", true);
+	showResizeHandle = conf.readEntry("showResizeHandle", true);
 	titlebarGradientType = conf.readNumEntry("titlebarGradientType",
 		KPixmapEffect::DiagonalGradient);
 
@@ -153,11 +163,11 @@ void GlowClientGlobals::readConfig()
 	_config->load(this);
 }
 
-QValueList< GlowClientGlobals::BorderSize >
+Q3ValueList< GlowClientGlobals::BorderSize >
 GlowClientGlobals::borderSizes() const
 {
     // the list must be sorted
-    return QValueList< BorderSize >() << BorderNormal <<
+    return Q3ValueList< BorderSize >() << BorderNormal <<
 	BorderLarge << BorderVeryLarge <<  BorderHuge <<
 	BorderVeryHuge << BorderOversized;
 }
@@ -257,7 +267,6 @@ bool GlowClientGlobals::createPixmaps()
 		if (! createPixmap(static_cast<PixmapType>(type), true))
 			return false;
 	}
-
 	return true;
 }
 
@@ -284,7 +293,7 @@ const QString GlowClientGlobals::getPixmapTypeName(PixmapType type)
 		case(Close):
 			return "Close";
 		default:
-			return QString::null;
+			return QString();
 	}
 }
 
@@ -419,7 +428,7 @@ void GlowClient::paintEvent( QPaintEvent * )
 	QColor titleBlendColor = options()->color(ColorTitleBlend, isActive());
 	QColor bgColor = widget()->colorGroup().background();
 	QPainter p;
-	QPointArray pArray, pArray2, pArray3, pArray4;
+	Q3PointArray pArray, pArray2, pArray3, pArray4;
 
 	// pixmap for title bar
 	QSize tBSize(width(), r_title.height());
@@ -443,10 +452,10 @@ void GlowClient::paintEvent( QPaintEvent * )
 		p.setPen(options()->color(ColorFont, isActive()));
 		p.drawText(r_title.x(), 0,
 			r_title.width(), r_title.height(),
-			Qt::AlignLeft | Qt::AlignVCenter | Qt::SingleLine, caption());
+			Qt::AlignLeft | Qt::AlignVCenter | Qt::TextSingleLine, caption());
 	
 		// draw split color beneath buttons top right
-		pArray4 = QPointArray(4);
+		pArray4 = Q3PointArray(4);
 		pArray4.setPoint(0, tBSize.width()-1, tBSize.height()/2-1);
 		pArray4.setPoint(1, r_title.x()+r_title.width()-1+tBSize.height()/2,
 			tBSize.height()/2-1);
@@ -457,7 +466,7 @@ void GlowClient::paintEvent( QPaintEvent * )
 		p.drawPolygon(pArray4);
 				
 		// draw borders
-		pArray = QPointArray(3);
+		pArray = Q3PointArray(3);
 		pArray.setPoint(0, tBSize.width()-1, tBSize.height()/2-1);
 		pArray.setPoint(1, r_title.x()+r_title.width()-1+tBSize.height()/2,
 			tBSize.height()/2-1);
@@ -466,7 +475,7 @@ void GlowClient::paintEvent( QPaintEvent * )
 		p.drawPolyline(pArray);
 		p.drawLine (0, tBSize.height()-1, r_title.x()+r_title.width()-1, tBSize.height()-1);
 
-		pArray2 = QPointArray(3);
+		pArray2 = Q3PointArray(3);
 		pArray2.setPoint(0, 1, tBSize.height()-2);
 		pArray2.setPoint(1, 1, 1);
 		pArray2.setPoint(2, tBSize.width()-2, 1);
@@ -474,7 +483,7 @@ void GlowClient::paintEvent( QPaintEvent * )
 		p.drawPolyline(pArray2);
 	}
 
-	pArray3 = QPointArray(4);
+	pArray3 = Q3PointArray(4);
 	pArray3.setPoint(0, 0, tBSize.height()-1);
 	pArray3.setPoint(1, 0, 0);
 	pArray3.setPoint(2, tBSize.width()-1, 0);
@@ -526,16 +535,10 @@ void GlowClient::showEvent( QShowEvent * )
 
 void GlowClient::mouseDoubleClickEvent( QMouseEvent *e )
 {
-	if(e->button() == LeftButton && _title_spacer->geometry().contains(e->pos()))
+	if(e->button() == Qt::LeftButton && _title_spacer->geometry().contains(e->pos()))
 		titlebarDblClickOperation();
 }
 
-void GlowClient::wheelEvent( QWheelEvent *e )
-{
-    if (isSetShade() || QRect( 0, 0, width(), titleHeight ).contains(e->pos()))
-        titlebarMouseWheelOperation( e->delta());
-}
-
 void GlowClient::activeChange()
 {
 	updateButtonPixmaps();
@@ -649,7 +652,7 @@ void GlowClient::createButtons()
 	QSize size = globals->theme()->buttonSize;
 
 	m_stickyButton = factory->createGlowButton(widget(),
-					"StickyButton", isOnAllDesktops()?i18n("Not on all desktops"):i18n("On all desktops"), LeftButton|RightButton);
+					"StickyButton", isOnAllDesktops()?i18n("Not on all desktops"):i18n("On all desktops"), Qt::LeftButton|Qt::RightButton);
 	m_stickyButton->setFixedSize(size);
 	connect(m_stickyButton, SIGNAL(clicked()), this, SLOT(toggleOnAllDesktops()));
 	m_buttonList.insert(m_buttonList.end(), m_stickyButton);
@@ -667,7 +670,7 @@ void GlowClient::createButtons()
 	m_buttonList.insert(m_buttonList.end(), m_minimizeButton);
 
 	m_maximizeButton=factory->createGlowButton(widget(),
-					"MaximizeButton", i18n("Maximize"), LeftButton|MidButton|RightButton);
+					"MaximizeButton", i18n("Maximize"), Qt::LeftButton|Qt::MidButton|Qt::RightButton);
 	m_maximizeButton->setFixedSize(size);
 	connect(m_maximizeButton, SIGNAL(clicked()), this, SLOT(slotMaximize()));
 	m_buttonList.insert(m_buttonList.end(), m_maximizeButton);
@@ -876,9 +879,6 @@ bool GlowClient::eventFilter( QObject* o, QEvent* e )
 	case QEvent::Show:
 	    showEvent( static_cast< QShowEvent* >( e ));
 	    return true;
-	case QEvent::Wheel:
-	    wheelEvent( static_cast< QWheelEvent* >( e ));
-	    return true;
 	default:
 	    break;
 	}
